=== modified file 'config.yaml'
--- config.yaml	2014-06-01 14:26:17 +0000
+++ config.yaml	2014-06-02 18:37:32 +0000
@@ -105,3 +105,8 @@
           juju-myservice-0
       If you're running multiple environments with the same services in them
       this allows you to differentiate between them.
+  libvirt_image_backend:
+    type: string
+    description:
+      Tell Nova which libvirt image backend to use. Supported backends are rbd and lvm.
+      If no backend is specified, the Nova default is used (probably qcow2).

=== modified file 'hooks/nova_compute_context.py'
--- hooks/nova_compute_context.py	2014-06-01 14:26:17 +0000
+++ hooks/nova_compute_context.py	2014-06-02 18:37:32 +0000
@@ -12,10 +12,16 @@
     related_units,
     service_name,
     unit_get,
+    WARNING,
     ERROR,
 )
 
-from charmhelpers.contrib.openstack.utils import get_host_ip, os_release
+from charmhelpers.contrib.openstack.utils import (
+    get_host_ip,
+    os_release,
+    get_os_version_package,
+    get_os_version_codename
+)
 from charmhelpers.contrib.network.ovs import add_bridge
 
 
@@ -128,6 +134,16 @@
         ctxt['rbd_secret_uuid'] = CEPH_SECRET_UUID
         ctxt['rbd_pool'] = 'nova'
 
+        if config('libvirt_image_backend') == 'rbd':
+            os_ver = get_os_version_package('ceph-common')
+            if float(os_ver) >= float(get_os_version_codename('havana')):
+                ctxt['libvirt_images_type'] = 'rbd'
+            else:
+                log("RBD imagebackend only supported in openstack >= Havana "
+                    "- ignoring", level=WARNING)
+        elif config('libvirt_image_backend') == 'lvm':
+            ctxt['libvirt_images_type'] = 'lvm'
+
         return ctxt
 
 

=== modified file 'revision'
--- revision	2014-03-27 11:08:20 +0000
+++ revision	2014-06-02 18:37:32 +0000
@@ -1,1 +1,1 @@
-132
+133

=== modified file 'templates/havana/nova.conf'
--- templates/havana/nova.conf	2014-04-16 08:26:38 +0000
+++ templates/havana/nova.conf	2014-06-02 18:37:32 +0000
@@ -35,11 +35,18 @@
 {% endif -%}
 
 {% if rbd_pool -%}
-rbd_pool = {{ rbd_pool }}
+libvirt_images_rbd_pool = {{ rbd_pool }}
 rbd_user = {{ rbd_user }}
 rbd_secret_uuid = {{ rbd_secret_uuid }}
 {% endif -%}
 
+{% if libvirt_image_backend -%}
+libvirt_images_type = {{ libvirt_images_type }}
+libvirt_inject_password=false
+libvirt_inject_key=false
+libvirt_inject_partition=-2
+{% endif -%}
+
 {% if neutron_plugin and neutron_plugin == 'ovs' -%}
 libvirt_vif_driver = nova.virt.libvirt.vif.LibvirtGenericVIFDriver
 {% if neutron_security_groups -%}

